/*= Rohde&Schwarz AMIQ I/Q Modulation Generator Include File ================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __rsamiq_HEADER
#define __rsamiq_HEADER

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#include <visa.h>
#include <visatype.h>

#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define rsamiq_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define rsamiq_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF1L)

#define rsamiq_DRIVE_C          "C:"
#define rsamiq_DRIVE_D          "D:"
#define rsamiq_DRIVE_E          "E:"
#define rsamiq_DRIVE_F          "F:"

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rsamiq_init (ViRsrc resourceName, ViBoolean IDQuery,
                               ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rsamiq_SineWave (ViSession instrumentHandle);
ViStatus _VI_FUNC rsamiq_EasyBERTConfig (ViSession instrumentHandle, ViInt32 type,
                                         ViBoolean dataPolarity,
                                         ViBoolean clockPolarity, ViInt32 masking,
                                         ViUInt32 count, ViUInt32 errors,
                                         ViInt32 restartSource);
ViStatus _VI_FUNC rsamiq_BERTFile (ViSession instrumentHandle, ViInt32 mode,
                                   ViString file);
ViStatus _VI_FUNC rsamiq_BERTFileQuery (ViSession instrumentHandle,
                                        ViChar _VI_FAR file[]);
ViStatus _VI_FUNC rsamiq_SetPRBSType (ViSession instrumentHandle, ViInt32 type);
ViStatus _VI_FUNC rsamiq_GetPRBSType (ViSession instrumentHandle, ViPInt32 type);
ViStatus _VI_FUNC rsamiq_SetBERTPol (ViSession instrumentHandle, ViBoolean signal,
                                     ViBoolean polarity);
ViStatus _VI_FUNC rsamiq_GetBERTPol (ViSession instrumentHandle, ViBoolean signal,
                                     ViPBoolean polarity);
ViStatus _VI_FUNC rsamiq_SetBERTMask (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsamiq_GetBERTMask (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rsamiq_SetBERTCond (ViSession instrumentHandle, ViUInt32 count,
                                      ViUInt32 errors);
ViStatus _VI_FUNC rsamiq_GetBERTCond (ViSession instrumentHandle, ViPUInt32 count,
                                      ViPUInt32 errors);
ViStatus _VI_FUNC rsamiq_SetBERTRestart (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rsamiq_GetBERTRestart (ViSession instrumentHandle,
                                         ViPInt32 source);
ViStatus _VI_FUNC rsamiq_GetBERTResult (ViSession instrumentHandle,
                                        ViPInt32 noofDataBits,
                                        ViPInt32 noofErrorBits,
                                        ViPReal64 bitErrorRate,
                                        ViPBoolean terminationStatus,
                                        ViPBoolean clockLineStatus,
                                        ViPBoolean dataLineStatus,
                                        ViPBoolean syncStatus);
ViStatus _VI_FUNC rsamiq_CalVals (ViSession instrumentHandle, ViInt32 mode,
                                  ViInt32 _VI_FAR values[]);
ViStatus _VI_FUNC rsamiq_SetADCCalFact (ViSession instrumentHandle, ViReal64 factor);
ViStatus _VI_FUNC rsamiq_GetADCCalFact (ViSession instrumentHandle,
                                        ViPReal64 factor);
ViStatus _VI_FUNC rsamiq_SetRefOscCal (ViSession instrumentHandle, ViInt32 factor);
ViStatus _VI_FUNC rsamiq_GetRefOscCal (ViSession instrumentHandle, ViPInt32 factor);
ViStatus _VI_FUNC rsamiq_SetMarkers (ViSession instrumentHandle, ViInt32 marker,
                                     ViInt32 _VI_FAR startIndex[],
                                     ViInt32 _VI_FAR stopIndex[],
                                     ViBoolean _VI_FAR markerState[],
                                     ViInt32 numberOfPoints);
ViStatus _VI_FUNC rsamiq_GetMarkers (ViSession instrumentHandle, ViInt32 marker,
                                     ViInt32 _VI_FAR startIndex[],
                                     ViInt32 _VI_FAR stopIndex[],
                                     ViBoolean _VI_FAR markerState[],
                                     ViPInt32 numberofPoints);
ViStatus _VI_FUNC rsamiq_SetMkrOut (ViSession instrumentHandle, ViInt32 marker,
                                    ViBoolean state);
ViStatus _VI_FUNC rsamiq_GetMkrOut (ViSession instrumentHandle, ViInt32 marker,
                                    ViPBoolean state);
ViStatus _VI_FUNC rsamiq_SetMkrDly (ViSession instrumentHandle, ViInt32 marker,
                                    ViInt32 delay);
ViStatus _VI_FUNC rsamiq_GetMkrDly (ViSession instrumentHandle, ViInt32 marker,
                                    ViPInt32 delay);
ViStatus _VI_FUNC rsamiq_memDir (ViSession instrumentHandle, ViInt32 mode,
                                 ViChar _VI_FAR fileList[], ViInt32 bufferSize,
                                 ViPInt32 numberOfItems);
ViStatus _VI_FUNC rsamiq_memCopy (ViSession instrumentHandle, ViString source,
                                  ViString destination);
ViStatus _VI_FUNC rsamiq_memDel (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsamiq_memSetCd (ViSession instrumentHandle, ViString directory);
ViStatus _VI_FUNC rsamiq_memGetCd (ViSession instrHamndle,
                                ViChar _VI_FAR directory[]); 
ViStatus _VI_FUNC rsamiq_memMd (ViSession instrumentHandle, ViString directory);
ViStatus _VI_FUNC rsamiq_memRd (ViSession instrumentHandle, ViString directory);
ViStatus _VI_FUNC rsamiq_memSetDrv (ViSession instrumentHandle, ViString drive);
ViStatus _VI_FUNC rsamiq_memGetDrv (ViSession instrumentHandle,
                                    ViChar _VI_FAR drive[]);
ViStatus _VI_FUNC rsamiq_memLoad (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsamiq_memName (ViSession instrumentHandle, ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsamiq_SetClkFreq (ViSession instrumentHandle, ViReal64 frequency,
                                     ViBoolean mode);
ViStatus _VI_FUNC rsamiq_GetClkFreq (ViSession instrumentHandle,
                                     ViPReal64 frequency);
ViStatus _VI_FUNC rsamiq_SetCorr (ViSession instrumentHandle, ViInt32 channel,
                                  ViReal64 gain, ViReal64 offset);
ViStatus _VI_FUNC rsamiq_GetCorr (ViSession instrumentHandle, ViInt32 channel,
                                  ViPReal64 gain, ViPReal64 offset);
ViStatus _VI_FUNC rsamiq_SetSkew (ViSession instrumentHandle, ViReal64 skew);
ViStatus _VI_FUNC rsamiq_GetSkew (ViSession instrumentHandle, ViPReal64 skew);
ViStatus _VI_FUNC rsamiq_SetClkOut (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rsamiq_GetClkOut (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rsamiq_SetOutFlt (ViSession instrumentHandle, ViInt32 channel,
                                    ViInt32 filter);
ViStatus _VI_FUNC rsamiq_GetOutFlt (ViSession instrumentHandle, ViInt32 channel,
                                    ViPInt32 filter);
ViStatus _VI_FUNC rsamiq_SetAmpl (ViSession instrumentHandle, ViInt32 channel,
                                  ViReal64 amplitude);
ViStatus _VI_FUNC rsamiq_GetAmpl (ViSession instrumentHandle, ViInt32 channel,
                                  ViPReal64 amplitude);
ViStatus _VI_FUNC rsamiq_SetOutState (ViSession instrumentHandle, ViInt32 channel,
                                      ViInt32 state);
ViStatus _VI_FUNC rsamiq_GetOutState (ViSession instrumentHandle, ViInt32 channel,
                                      ViPInt32 state);
ViStatus _VI_FUNC rsamiq_SetImpedance (ViSession instrumentHandle,
                                       ViBoolean impedance);
ViStatus _VI_FUNC rsamiq_GetImpedance (ViSession instrumentHandle,
                                       ViPBoolean impedance);
ViStatus _VI_FUNC rsamiq_SetRefOscSrc (ViSession instrumentHandle, ViBoolean source);
ViStatus _VI_FUNC rsamiq_GetRefOscSrc (ViSession instrumentHandle,
                                       ViPBoolean source);
ViStatus _VI_FUNC rsamiq_SetOutRes (ViSession instrumentHandle, ViInt32 resolution);
ViStatus _VI_FUNC rsamiq_GetOutRes (ViSession instrumentHandle, ViPInt32 resolution);
ViStatus _VI_FUNC rsamiq_SetBias (ViSession instrumentHandle, ViInt32 channel,
                                  ViReal64 bias);
ViStatus _VI_FUNC rsamiq_GetBias (ViSession instrumentHandle, ViInt32 channel,
                                  ViPReal64 bias);
ViStatus _VI_FUNC rsamiq_SetOutType (ViSession instrumentHandle, ViBoolean type);
ViStatus _VI_FUNC rsamiq_GetOutType (ViSession instrumentHandle, ViPBoolean type);
ViStatus _VI_FUNC rsamiq_SetAmplBal (ViSession instrumentHandle, ViInt32 channel,
                                     ViReal64 amplitude);
ViStatus _VI_FUNC rsamiq_GetAmplBal (ViSession instrumentHandle, ViInt32 channel,
                                     ViPReal64 amplitude);
ViStatus _VI_FUNC rsamiq_SetDigiOut (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rsamiq_GetDigiOut (ViSession instrumentHandle, ViPBoolean state);
ViStatus _VI_FUNC rsamiq_SetExtClk (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsamiq_GetExtClk (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rsamiq_SetTriggSlope (ViSession instrumentHandle, ViBoolean slope);
ViStatus _VI_FUNC rsamiq_GetTriggSlope (ViSession instrumentHandle,
                                        ViPBoolean slope);
ViStatus _VI_FUNC rsamiq_SetTriggMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsamiq_GetTriggMode (ViSession instrumentHandle, ViPInt32 mode);
ViStatus _VI_FUNC rsamiq_SetTriggSource (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rsamiq_GetTriggSource (ViSession instrumentHandle,
                                         ViPInt32 source);
ViStatus _VI_FUNC rsamiq_Calibrate (ViSession instrumentHandle, ViInt32 mode,
                                    ViPInt32 result);
ViStatus _VI_FUNC rsamiq_BERTCtrl (ViSession instrumentHandle, ViBoolean mode);
ViStatus _VI_FUNC rsamiq_TriggAbort (ViSession instrumentHandle);
ViStatus _VI_FUNC rsamiq_TriggArm (ViSession instrumentHandle);
ViStatus _VI_FUNC rsamiq_TriggImmediate (ViSession instrumentHandle);
ViStatus _VI_FUNC rsamiq_WaveformToRAM (ViSession instrumentHandle,
                                        ViReal64 _VI_FAR i[], ViReal64 _VI_FAR q[],
                                        ViInt32 size, ViPUInt32 bytesWritten);
ViStatus _VI_FUNC rsamiq_WaveformFileToRAM (ViSession instrumentHandle,
                                            ViString name);
ViStatus _VI_FUNC rsamiq_WaveformToDisk (ViSession instrumentHandle,
                                         ViReal64 _VI_FAR i[], ViReal64 _VI_FAR q[],
                                         ViInt32 size, ViString filename,
                                         ViPUInt32 bytesWritten);
ViStatus _VI_FUNC rsamiq_WaveformFileToDisk (ViSession instrumentHandle,
                                             ViString source, ViString destination);
ViStatus _VI_FUNC rsamiq_SetupDir (ViSession instrumentHandle,
                                   ViChar _VI_FAR fileList[], ViInt32 bufferSize,
                                   ViPInt32 numberOfItems);
ViStatus _VI_FUNC rsamiq_SetupCopy (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rsamiq_SetupDel (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsamiq_SetupSav (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsamiq_SetupRecall (ViSession instrumentHandle, ViString name);
ViStatus _VI_FUNC rsamiq_errorCheckState (ViSession instrumentHandle,
                                          ViBoolean state);
ViStatus _VI_FUNC rsamiq_SetGPIBAddress (ViSession instrumentHandle,
                                         ViInt32 GPIBAddress);
ViStatus _VI_FUNC rsamiq_GetSysOpt (ViSession instrumentHandle,
                                    ViChar _VI_FAR systemOptionString[]);
ViStatus _VI_FUNC rsamiq_writeInstrData (ViSession instrumentHandle,
                                         ViString writeBuffer);
ViStatus _VI_FUNC rsamiq_readInstrData (ViSession instrumentHandle,
                                        ViInt32 numberBytesToRead,
                                        ViChar _VI_FAR readBuffer[],
                                        ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsamiq_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsamiq_self_test (ViSession instrumentHandle,
                                    ViPInt16 selfTestResult,
                                    ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsamiq_self_test_SDRAM (ViSession instrumentHandle,
                                          ViPInt16 selfTestResult,
                                          ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsamiq_getAnalogBoardID (ViSession instrumentHandle,
                                           ViPInt32 boardID);
ViStatus _VI_FUNC rsamiq_getDiagTPOVal (ViSession instrumentHandle,
                                        ViInt32 testPointNumber,
                                        ViPReal64 testPointValue);
ViStatus _VI_FUNC rsamiq_error_query (ViSession instrumentHandle,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsamiq_error_message (ViSession instrumentHandle,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsamiq_revision_query (ViSession instrumentHandle,
                                         ViChar _VI_FAR instrumentDriverRevision[],
                                         ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsamiq_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

